@@ -30,6 +30,7 @@ class OvtpClient:
         self.authorized = False
         self.connected = False
         self.aes = None
+        self.loop = asyncio.new_event_loop()
 
     async def connect(self):
         self.reader, self.writer = await asyncio.open_connection(
@@ -37,6 +38,10 @@ class OvtpClient:
         )
         self.connected = True
 
+    async def reconnect(self):
+        self.reset()
+        await self.check_connection()
+
     async def close_connection(self):
         if self.verbose:
             print(f'Closing connection with {self.server_address}')
@@ -44,6 +49,9 @@ class OvtpClient:
         await self.writer.drain()
         self.writer.close()
         await self.writer.wait_closed()
+        self.reset()
+
+    def reset(self):
         self.reader = None
         self.writer = None
         self.encrypted_connection = False
@@ -340,9 +348,19 @@ class OvtpClient:
             # await self.writer.wait_closed()
             return rcv_data
 
+    def send_message_sync(self, message, timeout=2, retry=0):
+        return self.loop.run_until_complete(
+            self.send_message(message, timeout, retry)
+        )
+
     async def send_message(self, message, timeout=2, retry=0):
         await self.check_connection()
-        rcv = await self.send_data(self.server_address, data=message.encode(), timeout=timeout, retry=retry)
+        try:
+            rcv = await self.send_data(self.server_address, data=message.encode(), timeout=timeout, retry=retry)
+        except ConnectionResetError:
+            print('connection error')
+            await self.reconnect()
+            return await self.send_message(message, timeout=timeout, retry=retry)
         if rcv == 'Access denied':
             self.server_public_key = None
             self.authorized = False
